Documentation
¶
Overview ¶
Package xbpspkgdb provides types and functions for xbps plist access
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type FilterFunc ¶
FilterFunc is the type of the function called by the Pkgdb.Filter* methods
type Package ¶
type Package struct {
Alternatives map[string][]string `plist:"alternatives"`
Architecture string `plist:"architecture"`
AutomaticInstall bool `plist:"automatic-install"`
BuildDate string `plist:"build-date"`
BuildOptions string `plist:"build-options"`
ConfFiles []string `plist:"conf_files"`
Conflicts []string `plist:"conflicts"`
FilenameSha256 string `plist:"filename-sha256"`
FilenameSize int `plist:"filename-size"`
Homepage string `plist:"homepage"`
InstallDate string `plist:"install-date"`
InstallMsg []byte `plist:"install-msg"`
InstallScript []string `plist:"install-script"`
InstalledSize int `plist:"installed_size"`
License string `plist:"license"`
Maintainer string `plist:"maintainer"`
MetafileSha256 string `plist:"metafile-sha256"`
Pkgver string `plist:"pkgver"`
Preserve bool `plist:"preserve"`
Provides []string `plist:"provides"`
RemoveMsg []byte `plist:"remove-msg"`
RemoveScript []byte `plist:"remove-script"`
Replaces []string `plist:"replaces"`
Repolock bool `plist:"repolock"`
Repository string `plist:"repository"`
Reverts []string `plist:"reverts"`
RunDepends []string `plist:"run_depends"`
ShlibProvides []string `plist:"shlib-provides"`
ShlibRequires []string `plist:"shlib-requires"`
ShortDesc string `plist:"short_desc"`
SourceRevisions string `plist:"source-revisions"`
State string `plist:"state"`
}
Package hold all metadata
type Pkgdb ¶
Pkgdb maps a package name to its metadata
func DecodeFile ¶
DecodeFile is a convenience function that parses xbps plist files
func DecodeRepoData ¶
DecodeRepoData parses a stream of repodata
func DecodeRepoDataFile ¶
DecodeRepoDataFile is a convenience function to parse xbps repodata files
func (Pkgdb) Filter ¶
func (p Pkgdb) Filter(f FilterFunc) Pkgdb
Filter returns a new `Pkgdb` with filtered packages
func (Pkgdb) FilterKeys ¶
func (p Pkgdb) FilterKeys(f FilterFunc) []string
FilterKeys returns a slice of package names that match a `FilterFunc`
Click to show internal directories.
Click to hide internal directories.